"use strict";

require("../mocha-config");

var TouchMap = require('../../../main/js/map/TouchMap');
var ServerConnector = require('../ServerConnector-mock');
var chai = require('chai');
var assert = chai.assert;

describe('TouchMap', function () {
  it("constructor", function () {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);
    assert.ok(touchMap);
  });

  it("handleStart", function () {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);

    assert.notOk(touchMap.firstFingerId);

    var evt = document.createEvent('UIEvent');
    evt.initUIEvent('touchstart', true, true, window, null);

    evt.changedTouches = [{
      pageX: 200,
      pageY: 200,
      identifier: 1,
      clientX: 100,
      clientY: 100
    }];

    map.getElement().dispatchEvent(evt);

    assert.ok(touchMap.firstFingerId);
  });

  describe("handleEnd", function () {
    it("after move", function () {
      var map = helper.createCustomMap();
      var touchMap = new TouchMap(map);

      var evt = document.createEvent('UIEvent');
      evt.initUIEvent('touchstart', true, true, window, null);

      evt.changedTouches = [{
        pageX: 200,
        pageY: 200,
        identifier: 1,
        clientX: 100,
        clientY: 100
      }];

      map.getElement().dispatchEvent(evt);

      evt = document.createEvent('UIEvent');
      evt.initUIEvent('touchend', true, true, window, null);

      evt.changedTouches = [{
        pageX: 300,
        pageY: 300,
        identifier: 1,
        clientX: 200,
        clientY: 200
      }];

      map.getElement().dispatchEvent(evt);

      assert.notOk(touchMap.firstFingerId);
    });
    it("as a click", function () {
      return ServerConnector.getProject().then(function (project) {
        var map = helper.createCustomMap(project);
        var touchMap = new TouchMap(map);

        var evtLocation = {
          pageX: 10,
          pageY: 10,
          identifier: 0,
          clientX: 10,
          clientY: 10
        };

        var evt = document.createEvent('UIEvent');
        evt.initUIEvent('touchstart', true, true, window, null);
        evt.changedTouches = [evtLocation];
        map.getElement().dispatchEvent(evt);

        var clicked = false;
        google.maps.event.addListener(map.getGoogleMap(), "click", function () {
          clicked = true;
        });
        evt = document.createEvent('UIEvent');
        evt.initUIEvent('touchend', true, true, window, null);
        evt.changedTouches = [evtLocation];
        map.getElement().dispatchEvent(evt);

        assert.notOk(touchMap.firstFingerId);
        assert.ok(clicked);
      });
    });
  });

  describe("handleMove", function () {
    it("default", function () {
      var map = helper.createCustomMap();
      var coordinates = map.getGoogleMap().getCenter();
      new TouchMap(map);

      var evtLocation = {
        pageX: 10,
        pageY: 10,
        identifier: 0,
        clientX: 10,
        clientY: 10
      };

      var evt = document.createEvent('UIEvent');
      evt.initUIEvent('touchstart', true, true, window, null);
      evt.changedTouches = [evtLocation];
      map.getElement().dispatchEvent(evt);

      evt = document.createEvent('UIEvent');
      evt.initUIEvent('touchmove', true, true, window, null);
      evtLocation.pageX += 10;
      evtLocation.pageY += 10;
      evtLocation.clientX += 10;
      evtLocation.clientY += 10;
      evt.changedTouches = [evtLocation];
      map.getElement().dispatchEvent(evt);

      var coordinates2 = map.getGoogleMap().getCenter();

      assert.ok(coordinates.x !== coordinates2.x);
      assert.ok(coordinates.y !== coordinates2.y);

    });
  });
  it("updateCoordinates", function () {
    var map = helper.createCustomMap();

    var touchMap = new TouchMap(map);
    touchMap.firstFingerId = 1;

    var evt = document.createEvent('UIEvent');
    evt.initUIEvent('touchstart', true, true, window, null);

    evt.changedTouches = [{
      pageX: 200,
      pageY: 200,
      identifier: 1,
      clientX: 100,
      clientY: 100
    }];

    assert.notOk(touchMap.firstEndX);
    assert.notOk(touchMap.firstEndY);
    touchMap.updateCoordinates(evt.changedTouches[0]);
    assert.ok(touchMap.firstEndX);
    assert.ok(touchMap.firstEndY);
  });

  it("lineDistance", function () {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);

    var dist = touchMap.lineDistance(1, 1, 4, 5);
    assert.equal(5, dist);
  });

  it("zoomMap", function () {
    var map = helper.createCustomMap();
    var touchMap = new TouchMap(map);

    touchMap.zoomMap(1, 2, 4);
    assert.equal(map.getGoogleMap().getZoom(), 4);
  });
});
